Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(609)

Unified Diff: runtime/vm/regexp_parser.cc

Issue 1815333002: Simpler regex names: (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: sync Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/regexp_assembler_ir.cc ('k') | runtime/vm/regexp_test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/regexp_parser.cc
diff --git a/runtime/vm/regexp_parser.cc b/runtime/vm/regexp_parser.cc
index 7b0e01a478def31d88085172c21432df03af6038..c4d471ae37f81f424ce2250bee71cba7e1a7dfaf 100644
--- a/runtime/vm/regexp_parser.cc
+++ b/runtime/vm/regexp_parser.cc
@@ -220,14 +220,14 @@ bool RegExpParser::ParseFunction(ParsedFunction *parsed_function) {
VMTagScope tagScope(parsed_function->thread(),
VMTag::kCompileParseRegExpTagId);
Zone* zone = parsed_function->zone();
- JSRegExp& regexp = JSRegExp::Handle(parsed_function->function().regexp());
+ RegExp& regexp = RegExp::Handle(parsed_function->function().regexp());
const String& pattern = String::Handle(regexp.pattern());
const bool multiline = regexp.is_multi_line();
RegExpCompileData* compile_data = new(zone) RegExpCompileData();
if (!RegExpParser::ParseRegExp(pattern, multiline, compile_data)) {
// Parsing failures are handled in the JSRegExp factory constructor.
UNREACHABLE();
}
« no previous file with comments | « runtime/vm/regexp_assembler_ir.cc ('k') | runtime/vm/regexp_test.cc » ('j') | no next file with comments »
@@ -220,14 +220,14 @@ bool RegExpParser::ParseFunction(ParsedFunction *parsed_function) {
RegExpCompileData* compile_data = new(zone) RegExpCompileData();
if (!RegExpParser::ParseRegExp(pattern, multiline, compile_data)) {
- // Parsing failures are handled in the JSRegExp factory constructor.
+ // Parsing failures are handled in the RegExp factory constructor.
UNREACHABLE();
}

Powered by Google App Engine
This is Rietveld 408576698